==> senior_platform_authentication_ui-6.0.2.tar.gz: example/lib/biometric_settings.dart <==
import 'package:flutter/material.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_platform_authentication_ui/senior_platform_authentication_ui.dart';

class BiometricSettings extends StatefulWidget {
  const BiometricSettings({super.key});

  @override
  State<BiometricSettings> createState() => _BiometricSettingsState();
}

class _BiometricSettingsState extends State<BiometricSettings> {
  bool isBiometricUserEnabled = false;
  bool biometricAvailable = false;
  final GetStoredUserUsecase getStoredUserUsecase = GetStoredUserUsecase();
  final AuthenticationBloc authenticationBloc = AuthenticationBloc();
  final GetStoredTokenUsecase getStoredTokenUsecase = GetStoredTokenUsecase();
  final StoreAuthenticationDataUsecase storeAuthenticationDataUsecase =
      StoreAuthenticationDataUsecase();
  final BiometricAvailableUsecase biometricAvailableUseCase =
      BiometricAvailableUsecase();

  @override
  void initState() {
    loadData();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: SeniorText.labelBold(
          'Configurações de biometria',
          color: Colors.white,
        ),
      ),
      body: Builder(builder: (context) {
        return Column(
          children: [
            Padding(
              padding: const EdgeInsets.symmetric(
                vertical: SeniorSpacing.small,
              ),
              child: ListTile(
                contentPadding: const EdgeInsets.symmetric(
                  horizontal: SeniorSpacing.normal,
                  vertical: SeniorSpacing.normal,
                ),
                title: SeniorText.bodyBold(
                  'Entrar com biometria ou código do celular.',
                ),
                subtitle: Padding(
                  padding: const EdgeInsets.only(
                    top: SeniorSpacing.xxsmall,
                  ),
                  child: SeniorText.body(
                    'Quando esta função estiver ativada, você precisará usar a biometria ou o código para desbloquear o aplicativo.',
                  ),
                ),
                trailing: Container(
                  margin: const EdgeInsets.only(
                    top: SeniorSpacing.small,
                  ),
                  child: SizedBox(
                    height: SeniorSpacing.medium,
                    width: SeniorSpacing.xbig,
                    child: Center(
                      child: SeniorSwitch(
                        disabled: false,
                        value: isBiometricUserEnabled,
                        onChanged: (_) async {
                          if (isBiometricUserEnabled) {
                            await loadData();
                            await disableBiometric();
                            setState(() {});
                          } else {
                            await loadData();
                            await enableBiometric();
                            setState(() {});
                          }
                        },
                        titlePosition: SeniorSwitchTitlePosition.right,
                      ),
                    ),
                  ),
                ),
              ),
            ),
            SeniorButton(
              label: 'Voltar',
              onPressed: () => Navigator.pop(context),
              style: const SeniorButtonStyle(backgroundColor: Colors.blue),
            ),
          ],
        );
      }),
    );
  }

  Future<void> loadData() async {
    final responseUser = await getStoredUserUsecase.call(const UserName());
    if (SeniorAuthentication.enableBiometryOnly) {
      biometricAvailable = await biometricAvailableUseCase.call(NoParams());
    }
    {
      biometricAvailable = true;
    }

    setState(() {
      isBiometricUserEnabled =
          (responseUser != null && responseUser.activeBiometry);
    });
  }

  Future<void> enableBiometric() async {
    if (!biometricAvailable) {
      ScaffoldMessenger.of(context).showSnackBar(
        const SnackBar(
          content: Text(
              'Para utilizar esta opção, por favor, ative a biometria ou outro método de segurança nas configurações do seu dispositivo. Retorne ao aplicativo e habilite a opção em Configurações.'), // Exibir a mensagem de erro capturada

          duration: Duration(seconds: 5),
        ),
      );
    } else {
      const username = UserName();
      final responseUser = await getStoredUserUsecase(username);
      final token = await getStoredTokenUsecase(username);

      final biometricStatus =
          await authenticationBloc.onAuthenticationBiometricAuthRequested(
        biometricMessage: 'Entrar com biometria ou código do celular.',
      );

      if (biometricStatus == BiometryStatus.success) {
        if (responseUser != null) {
          final updatedUser = responseUser.copyWith(
            activeBiometry: biometricStatus == BiometryStatus.success,
          );
          isBiometricUserEnabled = biometricStatus == BiometryStatus.success;

          await storeAuthenticationDataUsecase(
            AuthenticationData(
              user: updatedUser,
              token: token,
            ),
          );
        }
      }

      if (biometricStatus == BiometryStatus.error) {
        ScaffoldMessenger.of(context).showSnackBar(
          const SnackBar(
            content: Text(
                'Para utilizar esta opção, por favor, ative a biometria ou outro método de segurança nas configurações do seu dispositivo. Retorne ao aplicativo e habilite a opção em Configurações.'), // Exibir a mensagem de erro capturada

            duration: Duration(seconds: 5),
          ),
        );
      }
    }
  }

  Future<void> disableBiometric() async {
    const username = UserName();
    final responseUser = await getStoredUserUsecase(username);
    final token = await getStoredTokenUsecase(username);

    final biometricStatus =
        await authenticationBloc.onAuthenticationBiometricAuthRequested(
      biometricMessage: 'Entrar com biometria ou código do celular.',
    );

    if (biometricStatus == BiometryStatus.success ||
        biometricStatus == BiometryStatus.error) {
      if (responseUser != null) {
        final updatedUser = responseUser.copyWith(
          activeBiometry: false,
        );
        isBiometricUserEnabled = false;
        await storeAuthenticationDataUsecase(
          AuthenticationData(
            user: updatedUser,
            token: token,
          ),
        );
      }
    }
  }
}

==> senior_platform_authentication_ui-6.1.0.tar.gz: example/lib/biometric_settings.dart <==
import 'package:flutter/material.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_platform_authentication_ui/senior_platform_authentication_ui.dart';

class BiometricSettings extends StatefulWidget {
  const BiometricSettings({super.key});

  @override
  State<BiometricSettings> createState() => _BiometricSettingsState();
}

class _BiometricSettingsState extends State<BiometricSettings> {
  bool isBiometricUserEnabled = false;
  bool biometricAvailable = false;
  final GetStoredUserUsecase getStoredUserUsecase = GetStoredUserUsecase();
  final AuthenticationBloc authenticationBloc = AuthenticationBloc();
  final GetStoredTokenUsecase getStoredTokenUsecase = GetStoredTokenUsecase();
  final StoreAuthenticationDataUsecase storeAuthenticationDataUsecase =
      StoreAuthenticationDataUsecase();
  final BiometricAvailableUsecase biometricAvailableUseCase =
      BiometricAvailableUsecase();

  @override
  void initState() {
    loadData();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: SeniorText.labelBold(
          'Configurações de biometria',
          color: Colors.white,
        ),
      ),
      body: Builder(builder: (context) {
        return Column(
          children: [
            Padding(
              padding: const EdgeInsets.symmetric(
                vertical: SeniorSpacing.small,
              ),
              child: ListTile(
                contentPadding: const EdgeInsets.symmetric(
                  horizontal: SeniorSpacing.normal,
                  vertical: SeniorSpacing.normal,
                ),
                title: SeniorText.bodyBold(
                  'Entrar com biometria ou código do celular.',
                ),
                subtitle: Padding(
                  padding: const EdgeInsets.only(
                    top: SeniorSpacing.xxsmall,
                  ),
                  child: SeniorText.body(
                    'Quando esta função estiver ativada, você precisará usar a biometria ou o código para desbloquear o aplicativo.',
                  ),
                ),
                trailing: Container(
                  margin: const EdgeInsets.only(
                    top: SeniorSpacing.small,
                  ),
                  child: SizedBox(
                    height: SeniorSpacing.medium,
                    width: SeniorSpacing.xbig,
                    child: Center(
                      child: SeniorSwitch(
                        disabled: false,
                        value: isBiometricUserEnabled,
                        onChanged: (_) async {
                          if (isBiometricUserEnabled) {
                            await loadData();
                            await disableBiometric();
                            setState(() {});
                          } else {
                            await loadData();
                            await enableBiometric();
                            setState(() {});
                          }
                        },
                        titlePosition: SeniorSwitchTitlePosition.right,
                      ),
                    ),
                  ),
                ),
              ),
            ),
            SeniorButton(
              label: 'Voltar',
              onPressed: () => Navigator.pop(context),
              style: const SeniorButtonStyle(backgroundColor: Colors.blue),
            ),
          ],
        );
      }),
    );
  }

  Future<void> loadData() async {
    final responseUser = await getStoredUserUsecase.call(const UserName());
    if (SeniorAuthentication.enableBiometryOnly) {
      biometricAvailable = await biometricAvailableUseCase.call(NoParams());
    }
    {
      biometricAvailable = true;
    }

    setState(() {
      isBiometricUserEnabled =
          (responseUser != null && responseUser.activeBiometry);
    });
  }

  Future<void> enableBiometric() async {
    if (!biometricAvailable) {
      ScaffoldMessenger.of(context).showSnackBar(
        const SnackBar(
          content: Text(
              'Para utilizar esta opção, por favor, ative a biometria ou outro método de segurança nas configurações do seu dispositivo. Retorne ao aplicativo e habilite a opção em Configurações.'), // Exibir a mensagem de erro capturada

          duration: Duration(seconds: 5),
        ),
      );
    } else {
      const username = UserName();
      final responseUser = await getStoredUserUsecase(username);
      final token = await getStoredTokenUsecase(username);

      final biometricStatus =
          await authenticationBloc.onAuthenticationBiometricAuthRequested(
        biometricMessage: 'Entrar com biometria ou código do celular.',
      );

      if (biometricStatus == BiometryStatus.success) {
        if (responseUser != null) {
          final updatedUser = responseUser.copyWith(
            activeBiometry: biometricStatus == BiometryStatus.success,
          );
          isBiometricUserEnabled = biometricStatus == BiometryStatus.success;

          await storeAuthenticationDataUsecase(
            AuthenticationData(
              user: updatedUser,
              token: token,
            ),
          );
        }
      }

      if (biometricStatus == BiometryStatus.error && context.mounted) {
        ScaffoldMessenger.of(context).showSnackBar(
          const SnackBar(
            content: Text(
                'Para utilizar esta opção, por favor, ative a biometria ou outro método de segurança nas configurações do seu dispositivo. Retorne ao aplicativo e habilite a opção em Configurações.'), // Exibir a mensagem de erro capturada
            duration: Duration(seconds: 5),
          ),
        );
      }
    }
  }

  Future<void> disableBiometric() async {
    const username = UserName();
    final responseUser = await getStoredUserUsecase(username);
    final token = await getStoredTokenUsecase(username);

    final biometricStatus =
        await authenticationBloc.onAuthenticationBiometricAuthRequested(
      biometricMessage: 'Entrar com biometria ou código do celular.',
    );

    if (biometricStatus == BiometryStatus.success ||
        biometricStatus == BiometryStatus.error) {
      if (responseUser != null) {
        final updatedUser = responseUser.copyWith(
          activeBiometry: false,
        );
        isBiometricUserEnabled = false;
        await storeAuthenticationDataUsecase(
          AuthenticationData(
            user: updatedUser,
            token: token,
          ),
        );
      }
    }
  }
}
